@@ -1,5 +1,5 @@
 package Date::QuarterOfYear;
-$Date::QuarterOfYear::VERSION = '0.04';
+$Date::QuarterOfYear::VERSION = '0.05';
 use 5.006;
 use strict;
 use warnings;
@@ -34,9 +34,12 @@ sub _dwim_date
         elsif (reftype($param)) {
             croak "you can't pass a reference of type ".reftype($param);
         }
-        elsif ($param =~ /^([0-9][0-9][0-9][0-9])-([0-9][0-9])-([0-9][0-9])$/) {
+        elsif ($param =~ /^([0-9][0-9][0-9][0-9])-([0-9]{1,2})-([0-9]{1,2})$/) {
             return { year => $1, month => $2, day => $3 };
         }
+        elsif ($param !~ /^[0-9]+$/) {
+            croak "unexpected date format in '$param'\n";
+        }
 
         my @tm = gmtime($param);
         return { year => $tm[5] + 1900, month => $tm[4]+1, day => $tm[3] };
